@@ -10,6 +10,5 @@ if tf.__version__[0] == "1":
     tf.enable_eager_execution()
 
 from . import nn, utils, data, datasets, layers, sparse
-from tf_geometric.data.graph import Graph, BatchGraph
-from tf_geometric.sparse.sparse_matrix import SparseMatrix
-from tf_geometric.sparse.sparse_adj import SparseAdj
+from .data.graph import Graph, BatchGraph
+from .sparse.sparse_adj import SparseAdj
